<?php
/**
 * Oded functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Oded
 */

if ( ! function_exists( 'oded_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
	function oded_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Oded, use a find and replace
		 * to change 'oded' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'oded', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'oded' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'oded_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		add_editor_style( 'editor-style.css' );
	}
endif;

add_action( 'after_setup_theme', 'oded_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function oded_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'oded_content_width', 640 );
}
add_action( 'after_setup_theme', 'oded_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function oded_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'oded' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add your right sidebar widgets here.', 'oded' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="panel panel-primary">',
		'after_widget'  => '</div></section>',
		'before_title'  => '<div class="panel-heading"><h3 class="panel-title">',
		'after_title'   => '</h3></div>',
	) );
}
add_action( 'widgets_init', 'oded_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function oded_scripts() {
	wp_enqueue_style( 'oded-bootstrap', get_template_directory_uri() . '/external-assets/bootstrap.min.css' );

	wp_enqueue_style( 'oded-material', get_template_directory_uri() . '/external-assets/material.min.css' );

	wp_enqueue_style( 'oded-style', get_stylesheet_uri() );

	wp_enqueue_style( 'dashicons' );

	wp_enqueue_style( 'google-fonts', '//fonts.googleapis.com/css?family=Lato:300,400|Merriweather:300,400', array(), '20151215', true );

	wp_enqueue_script( 'oded-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );

	wp_enqueue_script( 'oded-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	wp_enqueue_script( 'oded-bootstrap-js', get_template_directory_uri() . '/external/bootstrap.min.js', array(), '20151215', true );

	wp_enqueue_script( 'oded-material-js', get_template_directory_uri() . '/external/material.min.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'oded_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
